@@ -9,6 +9,6 @@ class MNISTIterator(SequenceDatasetIterator):
 
     def __init__(self, samples_stream: StreamedResource, targets_stream: StreamedResource):
         targets = [int(target) for target in torch.load(targets_stream)]
-        dataset_sequences = [torch.load(samples_stream), targets]
+        dataset_sequences = [torch.load(samples_stream), targets, targets]
         samples_stream.close()
         super().__init__(dataset_sequences=dataset_sequences)
